// Copyright © 2017 DWANGO Co., Ltd.
/**
 * DataBus上に流すデータを多重化する機構
 */
var MultiplexDataBus = (function () {
    function MultiplexDataBus(dataBus, dataId) {
        var _this = this;
        this._handlers = [];
        this._dataBus = dataBus;
        this._dataId = dataId;
        this._handler = function () {
            var data = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                data[_i - 0] = arguments[_i];
            }
            if (data.length < 1 || data[0] !== _this._dataId)
                return;
            data.splice(0, 1);
            var r = [];
            for (var _a = 0, _b = _this._handlers; _a < _b.length; _a++) {
                var h = _b[_a];
                if (h.apply(_this, data)) {
                    r.push(h);
                }
            }
            for (var _c = 0; _c < r.length; _c++) {
                var h = r[_c];
                _this.removeHandler(h);
            }
        };
        this._dataBus.addHandler(this._handler);
    }
    MultiplexDataBus.prototype.destroy = function () {
        if (!this._dataBus)
            return;
        this.removeAllHandlers();
        this._dataBus.removeHandler(this._handler);
        this._dataBus = undefined;
    };
    MultiplexDataBus.prototype.destroyed = function () {
        return !this._dataBus;
    };
    MultiplexDataBus.prototype.send = function () {
        var data = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            data[_i - 0] = arguments[_i];
        }
        if (!this._dataBus)
            return;
        data.unshift(this._dataId);
        this._dataBus.send.apply(this._dataBus, data);
    };
    MultiplexDataBus.prototype.addHandler = function (handler) {
        if (!this._dataBus)
            return;
        this._handlers.push(handler);
    };
    MultiplexDataBus.prototype.removeHandler = function (handler) {
        if (!this._dataBus || this._handlers.indexOf(handler) < 0)
            return;
        this._handlers.splice(this._handlers.indexOf(handler), 1);
    };
    MultiplexDataBus.prototype.removeAllHandlers = function () {
        if (!this._dataBus)
            return;
        this._handlers = [];
    };
    return MultiplexDataBus;
})();
exports.MultiplexDataBus = MultiplexDataBus;
